==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/man.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>aroundme.css);

-->
</style>
<!--[if IE]>
<style type="text/css">
@import url(<?php echo $templatePath;?>aroundme-IE.css);
</style>
<![endif]-->

</head>

<body>

<div id="content">
	<div class="box_top">
		<?php echo $lang['section_man'];?><br />
	</div>
	
	<div class="box_mid" style="padding: 9px;">
		<?php
		if (isset($man_paragraphs)) {
		?>
		<table cellpadding="4" cellspacing="0" border="0" width="100%">
			<?php
			foreach($man_paragraphs as $key => $i):
			if (!empty($lang['man'][$i])) {
			?>
			<tr>
				<td>
					<?php echo nl2br($lang['man'][$i]);?><br />
				</td>
			</tr>
			<?php
			}
			endforeach;
			?>
		</table>
		<?php }?>
	</div>
	
	<div id="box_bottom">
		<table cellpadding="0" cellspacing="0" border="0" width="100%">
			<tr>
				<td align="left">
					<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
				</td>
				<td align="left">
					<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
				</td>
				<td align="right">
					<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
				</td>
			</tr>
		</table>
	</div>
</div>

</body>
</html>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/template/barnraiser_01/man.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<!DOCTYPE html
PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo $lang['txt_page_title'];?></title>
<style type="text/css">
<!--
@import url(<?php echo $templatePath;?>aroundme.css);

-->
</style>
<!--[if IE]>
<style type="text/css">
@import url(<?php echo $templatePath;?>aroundme-IE.css);
</style>
<![endif]-->

</head>

<body>
<div id="content">
	<div class="box_top">
		<?php echo $lang['section_man'];?><br />
	</div>
	
	<div class="box_mid" style="padding: 9px;">
		<?php
		if (isset($man)) {
		?>
		<table cellpadding="4" cellspacing="0" border="0" width="100%">
			<?php
			//create a toc
			foreach($man as $key => $i):
			?>
			<tr>
				<td>
					<a href="#<?php echo $key;?>"><?php echo $i['title'];?></a><br />
				</td>
			</tr>
			<?php
			endforeach;
			?>
		</table>
		
		
		<table cellpadding="4" cellspacing="0" border="0" width="100%">
			<?php
			//create the content
			foreach($man as $key => $i):
			?>
			<tr>
				<td>
					<a name="<?php echo $key;?>">
					<?php echo $i['man'];?><br />
				</td>
			</tr>
			<tr>
				<td align="right">
					<a href="#"><?php echo $lang['href_top'];?></a><br />
				</td>
			</tr>
			<?php
			endforeach;
			?>
		</table>
		<?php }?>
	</div>
	
	<div id="box_bottom">
		<table cellpadding="0" cellspacing="0" border="0" width="100%">
			<tr>
				<td align="left">
					<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
				</td>
				<td align="left">
					<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
				</td>
				<td align="right">
					<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
				</td>
			</tr>
		</table>
	</div>
</div>

</body>
</html>
